# -*- coding: utf-8 -*-

__title__ = 'MK312'
__description__ = 'MK312 Communication Wrapper'
__url__ = 'https://github.com/Rubberfate/mk312com'
__version__ = '0.3.0'
__author__ = 'Rubberfate'
__author_email__ = 'rubberfate@gmail.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2021 Rubberfate'
